package com.bonus.canteen.core.basic.mapper;

import java.util.List;
import com.bonus.canteen.core.basic.domain.BasicSetting;

/**
 * 功能参数配置Mapper接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface BasicSettingMapper {
    /**
     * 查询功能参数配置
     * 
     * @param id 功能参数配置主键
     * @return 功能参数配置
     */
    public BasicSetting selectBasicSettingById(Long id);

    /**
     * 查询功能参数配置列表
     * 
     * @param basicSetting 功能参数配置
     * @return 功能参数配置集合
     */
    public List<BasicSetting> selectBasicSettingList(BasicSetting basicSetting);

    /**
     * 新增功能参数配置
     * 
     * @param basicSetting 功能参数配置
     * @return 结果
     */
    public int insertBasicSetting(BasicSetting basicSetting);

    /**
     * 修改功能参数配置
     * 
     * @param basicSetting 功能参数配置
     * @return 结果
     */
    public int updateBasicSetting(BasicSetting basicSetting);

    /**
     * 删除功能参数配置
     * 
     * @param id 功能参数配置主键
     * @return 结果
     */
    public int deleteBasicSettingById(Long id);

    /**
     * 批量删除功能参数配置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBasicSettingByIds(Long[] ids);
}
