package com.bonus.canteen.core.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.basic.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.basic.domain.BasicSetting;
import com.bonus.canteen.core.basic.service.IBasicSettingService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 功能参数配置Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "功能参数配置接口")
@RestController
@RequestMapping("/basic_setting")
public class BasicSettingController extends BaseController {
    @Autowired
    private IBasicSettingService basicSettingService;

    /**
     * 查询功能参数配置列表
     */
    @ApiOperation(value = "查询功能参数配置列表")
    //@RequiresPermissions("basic:setting:list")
    @GetMapping("/list")
    public TableDataInfo list(BasicSetting basicSetting) {
        startPage();
        List<BasicSetting> list = basicSettingService.selectBasicSettingList(basicSetting);
        return getDataTable(list);
    }

    /**
     * 导出功能参数配置列表
     */
    @ApiOperation(value = "导出功能参数配置列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:setting:export")
    @SysLog(title = "功能参数配置", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出功能参数配置")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BasicSetting basicSetting) {
        List<BasicSetting> list = basicSettingService.selectBasicSettingList(basicSetting);
        ExcelUtil<BasicSetting> util = new ExcelUtil<BasicSetting>(BasicSetting.class);
        util.exportExcel(response, list, "功能参数配置数据");
    }

    /**
     * 获取功能参数配置详细信息
     */
    @ApiOperation(value = "获取功能参数配置详细信息")
    //@RequiresPermissions("basic:setting:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(basicSettingService.selectBasicSettingById(id));
    }

    /**
     * 新增功能参数配置
     */
    @ApiOperation(value = "新增功能参数配置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:setting:add")
    @SysLog(title = "功能参数配置", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增功能参数配置")
    @PostMapping
    public AjaxResult add(@RequestBody BasicSetting basicSetting) {
        try {
            return toAjax(basicSettingService.insertBasicSetting(basicSetting));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改功能参数配置
     */
    @ApiOperation(value = "修改功能参数配置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:setting:edit")
    @SysLog(title = "功能参数配置", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改功能参数配置")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody BasicSetting basicSetting) {
        try {
            return toAjax(basicSettingService.updateBasicSetting(basicSetting));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除功能参数配置
     */
    @ApiOperation(value = "删除功能参数配置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:setting:remove")
    @SysLog(title = "功能参数配置", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除功能参数配置")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(basicSettingService.deleteBasicSettingByIds(ids));
    }
}
